@@ -26,6 +26,8 @@ from sphinx.testing import restructuredtext
 from sphinx.testing.util import assert_node
 from sphinx.writers.text import STDINDENT
 
+from tests.utils import extract_node
+
 TYPE_CHECKING = False
 if TYPE_CHECKING:
     from sphinx.testing.util import SphinxTestApp
@@ -239,7 +241,7 @@ def test_js_function(app):
         ),
     )
     assert_node(
-        doctree[1][0][1],
+        extract_node(doctree, 1, 0, 1),
         [
             desc_parameterlist,
             (
@@ -399,10 +401,14 @@ def test_jsfunction_signature_with_javascript_maximum_signature_line_length_equa
         no_index=False,
     )
     assert_node(
-        doctree[1][0][1],
+        extract_node(doctree, 1, 0, 1),
         [desc_parameterlist, desc_parameter, ([desc_sig_name, 'name'])],
     )
-    assert_node(doctree[1][0][1], desc_parameterlist, multi_line_parameter_list=False)
+    assert_node(
+        extract_node(doctree, 1, 0, 1),
+        desc_parameterlist,
+        multi_line_parameter_list=False,
+    )
 
 
 @pytest.mark.sphinx(
@@ -445,10 +451,14 @@ def test_jsfunction_signature_with_javascript_maximum_signature_line_length_forc
         no_index=False,
     )
     assert_node(
-        doctree[1][0][1],
+        extract_node(doctree, 1, 0, 1),
         [desc_parameterlist, desc_parameter, ([desc_sig_name, 'names'])],
     )
-    assert_node(doctree[1][0][1], desc_parameterlist, multi_line_parameter_list=False)
+    assert_node(
+        extract_node(doctree, 1, 0, 1),
+        desc_parameterlist,
+        multi_line_parameter_list=False,
+    )
 
 
 @pytest.mark.sphinx(
@@ -489,10 +499,14 @@ def test_jsfunction_signature_with_javascript_maximum_signature_line_length_brea
         no_index=False,
     )
     assert_node(
-        doctree[1][0][1],
+        extract_node(doctree, 1, 0, 1),
         [desc_parameterlist, desc_parameter, ([desc_sig_name, 'names'])],
     )
-    assert_node(doctree[1][0][1], desc_parameterlist, multi_line_parameter_list=True)
+    assert_node(
+        extract_node(doctree, 1, 0, 1),
+        desc_parameterlist,
+        multi_line_parameter_list=True,
+    )
 
 
 @pytest.mark.sphinx(
@@ -533,10 +547,14 @@ def test_jsfunction_signature_with_maximum_signature_line_length_equal(app):
         no_index=False,
     )
     assert_node(
-        doctree[1][0][1],
+        extract_node(doctree, 1, 0, 1),
         [desc_parameterlist, desc_parameter, ([desc_sig_name, 'name'])],
     )
-    assert_node(doctree[1][0][1], desc_parameterlist, multi_line_parameter_list=False)
+    assert_node(
+        extract_node(doctree, 1, 0, 1),
+        desc_parameterlist,
+        multi_line_parameter_list=False,
+    )
 
 
 @pytest.mark.sphinx(
@@ -577,10 +595,14 @@ def test_jsfunction_signature_with_maximum_signature_line_length_force_single(ap
         no_index=False,
     )
     assert_node(
-        doctree[1][0][1],
+        extract_node(doctree, 1, 0, 1),
         [desc_parameterlist, desc_parameter, ([desc_sig_name, 'names'])],
     )
-    assert_node(doctree[1][0][1], desc_parameterlist, multi_line_parameter_list=False)
+    assert_node(
+        extract_node(doctree, 1, 0, 1),
+        desc_parameterlist,
+        multi_line_parameter_list=False,
+    )
 
 
 @pytest.mark.sphinx(
@@ -621,10 +643,14 @@ def test_jsfunction_signature_with_maximum_signature_line_length_break(app):
         no_index=False,
     )
     assert_node(
-        doctree[1][0][1],
+        extract_node(doctree, 1, 0, 1),
         [desc_parameterlist, desc_parameter, ([desc_sig_name, 'names'])],
     )
-    assert_node(doctree[1][0][1], desc_parameterlist, multi_line_parameter_list=True)
+    assert_node(
+        extract_node(doctree, 1, 0, 1),
+        desc_parameterlist,
+        multi_line_parameter_list=True,
+    )
 
 
 @pytest.mark.sphinx(
@@ -661,8 +687,12 @@ def test_javascript_maximum_signature_line_length_overrides_global(app):
         no_index=False,
     )
     expected_sig = [desc_parameterlist, desc_parameter, [desc_sig_name, 'name']]
-    assert_node(doctree[1][0][1], expected_sig)
-    assert_node(doctree[1][0][1], desc_parameterlist, multi_line_parameter_list=False)
+    assert_node(extract_node(doctree, 1, 0, 1), expected_sig)
+    assert_node(
+        extract_node(doctree, 1, 0, 1),
+        desc_parameterlist,
+        multi_line_parameter_list=False,
+    )
 
 
 @pytest.mark.sphinx(
