@@ -27,9 +27,17 @@ from sphinx.ext.autosummary.generate import (
 from sphinx.ext.autosummary.generate import main as autogen_main
 from sphinx.testing.util import assert_node, etree_parse
 
+from tests.utils import extract_node
+
 if TYPE_CHECKING:
     from xml.etree.ElementTree import Element
 
+if sys.version_info[:2] >= (3, 15):
+    cached_dunder: tuple[str, ...] = ()
+else:
+    cached_dunder = ('__cached__',)
+
+
 html_warnfile = StringIO()
 
 
@@ -266,7 +274,7 @@ def test_autosummary_generate_content_for_module(app):
         '_Exc',
         '__all__',
         '__builtins__',
-        '__cached__',
+        *cached_dunder,
         '__doc__',
         '__file__',
         '__name__',
@@ -299,7 +307,7 @@ def test_autosummary_generate_content_for_module(app):
 
 @pytest.mark.sphinx('html', testroot='ext-autosummary', copy_test_root=True)
 def test_autosummary_generate_content_for_module___all__(app):
-    import autosummary_dummy_module
+    import autosummary_dummy_module  # ty: ignore[unresolved-import]
 
     template = Mock()
     app.config.autosummary_ignore_module_all = False
@@ -345,7 +353,7 @@ def test_autosummary_generate_content_for_module___all__(app):
 
 @pytest.mark.sphinx('html', testroot='ext-autosummary', copy_test_root=True)
 def test_autosummary_generate_content_for_module_skipped(app):
-    import autosummary_dummy_module
+    import autosummary_dummy_module  # ty: ignore[unresolved-import]
 
     template = Mock()
 
@@ -375,7 +383,7 @@ def test_autosummary_generate_content_for_module_skipped(app):
         '_Exc',
         '__all__',
         '__builtins__',
-        '__cached__',
+        *cached_dunder,
         '__doc__',
         '__file__',
         '__name__',
@@ -392,7 +400,7 @@ def test_autosummary_generate_content_for_module_skipped(app):
 
 @pytest.mark.sphinx('html', testroot='ext-autosummary', copy_test_root=True)
 def test_autosummary_generate_content_for_module_imported_members(app):
-    import autosummary_dummy_module
+    import autosummary_dummy_module  # ty: ignore[unresolved-import]
 
     template = Mock()
 
@@ -422,7 +430,7 @@ def test_autosummary_generate_content_for_module_imported_members(app):
         '_Exc',
         '__all__',
         '__builtins__',
-        '__cached__',
+        *cached_dunder,
         '__doc__',
         '__file__',
         '__loader__',
@@ -487,7 +495,7 @@ def test_autosummary_generate_content_for_module_imported_members_inherited_modu
         'InheritedAttrClass',
         '__all__',
         '__builtins__',
-        '__cached__',
+        *cached_dunder,
         '__doc__',
         '__file__',
         '__loader__',
@@ -548,23 +556,31 @@ def test_autosummary_generate(app):
             ),
         ],
     )
-    assert_node(doctree[4][0], addnodes.toctree, caption='An autosummary')
+    assert_node(extract_node(doctree, 4, 0), addnodes.toctree, caption='An autosummary')
 
-    assert len(doctree[3][0][0][2]) == 8
-    assert doctree[3][0][0][2][0].astext() == 'autosummary_dummy_module\n\n'
-    assert doctree[3][0][0][2][1].astext() == 'autosummary_dummy_module.Foo()\n\n'
-    assert doctree[3][0][0][2][2].astext() == 'autosummary_dummy_module.Foo.Bar()\n\n'
-    assert doctree[3][0][0][2][3].astext() == (
+    assert len(extract_node(doctree, 3, 0, 0, 2)) == 8
+    assert extract_node(doctree, 3, 0, 0, 2, 0).astext() == (
+        'autosummary_dummy_module\n\n'
+    )
+    assert extract_node(doctree, 3, 0, 0, 2, 1).astext() == (
+        'autosummary_dummy_module.Foo()\n\n'
+    )
+    assert extract_node(doctree, 3, 0, 0, 2, 2).astext() == (
+        'autosummary_dummy_module.Foo.Bar()\n\n'
+    )
+    assert extract_node(doctree, 3, 0, 0, 2, 3).astext() == (
         'autosummary_dummy_module.Foo.value\n\ndocstring'
     )
-    assert doctree[3][0][0][2][4].astext() == 'autosummary_dummy_module.bar(x[, y])\n\n'
-    assert doctree[3][0][0][2][5].astext() == (
+    assert extract_node(doctree, 3, 0, 0, 2, 4).astext() == (
+        'autosummary_dummy_module.bar(x[, y])\n\n'
+    )
+    assert extract_node(doctree, 3, 0, 0, 2, 5).astext() == (
         'autosummary_dummy_module.qux\n\na module-level attribute'
     )
-    assert doctree[3][0][0][2][6].astext() == (
+    assert extract_node(doctree, 3, 0, 0, 2, 6).astext() == (
         'autosummary_dummy_inherited_module.InheritedAttrClass()\n\n'
     )
-    assert doctree[3][0][0][2][7].astext() == (
+    assert extract_node(doctree, 3, 0, 0, 2, 7).astext() == (
         'autosummary_dummy_inherited_module.InheritedAttrClass.subclassattr\n\nother docstring'
     )
 
